@@ -11,9 +11,7 @@ any '/conditional' => sub {
     http_conditional {
         etag            => "x",
         last_modified   => $sometime,
-#       required        => true
-        } => sub {
-        "Condition met to execute the request..."
+        required        => true
     };
     "So we fall through now?"
 };
