@@ -10,7 +10,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use warnings;
 use strict;
@@ -45,7 +45,7 @@ to prevent lost-updates with unsafe-methods in a stateless api (like REST).
             required        => false,
         }
         
-        # do the real stuff, like updating
+        # do the real stuff, like updating or serializing
         
     };
 
@@ -170,15 +170,14 @@ options are set and returned in the appropriate HTTP Header Fields.
 
 register http_conditional => sub {
     my $self    = shift;
-    my $coderef = pop;
+    my $coderef = pop if ref($_[-1]) eq "CODE";
     my $args    = shift;
     
-    
-    unless ( $coderef && ref $coderef eq 'CODE' ) {
-        return sub {
-           warn "http_conditional: missing CODE-REF";
-        };
-    };
+#   unless ( $coderef && ref $coderef eq 'CODE' ) {
+#       return sub {
+#          warn "http_conditional: missing CODE-REF";
+#       };
+#   };
     
     # To understand the flow of the desicions the original text of the RFC has
     # been included so one can see that it does what the RFC says, not what the
@@ -210,7 +209,7 @@ register http_conditional => sub {
 #       warn "http_conditional: http_method_is_safe";
     };
     
-
+    
     # RFC 7232 Hypertext Transfer Protocol (HTTP/1.1): Conditional Requests
     #
     # Section 6. Precedence
@@ -402,7 +401,9 @@ STEP_6:
     }
     
     # RFC 7232
-    return;# $coderef->($self);
+    
+    return $coderef->($self) if $coderef;
+    return
     
 };
 
